import { OnDestroy, Component } from "@angular/core";
import { DialogService } from "./dialog.service";
import { Observable } from "rxjs";
import { DialogWrapperComponent } from "./dialog-wrapper.component";
/**
 * Abstract dialog
 * @template T - dialog data;
 * @template T1 - dialog result
 */
@Component({
  selector: "dialog",
  template: "",
})
export declare class DialogComponent<T, T1> implements OnDestroy {
  protected dialogService: DialogService;
  /**
   * Observer to return result from dialog
   */
  private observer;
  /**
   * Dialog result
   */
  protected result: T1;
  /**
   * Dialog wrapper (modal placeholder)
   */
  wrapper: DialogWrapperComponent;
  /**
   * Constructor
   * @param dialogService - instance of DialogService
   */
  constructor(dialogService: DialogService);
  /**
   *
   * @param data T
   * @return Observable<T1>
   */
  fillData(data: T): Observable<T1>;
  /**
   * Closes dialog
   */
  close(): void;
  /**
   * OnDestroy handler
   * Sends dialog result to observer
   */
  ngOnDestroy(): void;
}
